CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
101 lines
2.9 KiB
C++
101 lines
2.9 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
/**
|
|
* @addtogroup hipCreateTextureObject hipCreateTextureObject
|
|
* @{
|
|
* @ingroup TextureTest
|
|
*/
|
|
|
|
#define N 512
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Validates handling of invalid arguments for [hipCreateTextureObject](@ref
|
|
* hipCreateTextureObject):
|
|
* -# When output pointer to the texture object is `nullptr`
|
|
* - Expected output: do not return `hipSuccess`
|
|
* -# When resource descriptor is `nullptr`
|
|
* - Expected output: do not return `hipSuccess`
|
|
* -# When texture descriptor is `nullptr`
|
|
* - Expected output: do not return `hipSuccess`
|
|
* - Validates handling of invalid arguments for [hipDestroyTextureObject](@ref
|
|
* hipDestroyTextureObject):
|
|
* -# When texture object handle is `nullptr`
|
|
* - Expected output: return `hipSuccess`
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/texture/hipCreateTextureObject_ArgValidation.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - Textures supported on device
|
|
* - HIP_VERSION >= 5.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipCreateTextureObject_ArgValidation) {
|
|
CHECK_IMAGE_SUPPORT
|
|
|
|
float* texBuf;
|
|
hipError_t ret;
|
|
constexpr int xsize = 32;
|
|
hipResourceDesc resDesc;
|
|
hipTextureDesc texDesc;
|
|
hipTextureObject_t texObj;
|
|
|
|
// Initialization
|
|
HIP_CHECK(hipMalloc(&texBuf, N * sizeof(float)));
|
|
// Populate resource descriptor
|
|
memset(&resDesc, 0, sizeof(resDesc));
|
|
resDesc.resType = hipResourceTypeLinear;
|
|
resDesc.res.linear.devPtr = texBuf;
|
|
resDesc.res.linear.desc = hipCreateChannelDesc(xsize, 0, 0, 0, hipChannelFormatKindFloat);
|
|
resDesc.res.linear.sizeInBytes = N * sizeof(float);
|
|
|
|
// Populate texture descriptor
|
|
memset(&texDesc, 0, sizeof(texDesc));
|
|
texDesc.readMode = hipReadModeElementType;
|
|
|
|
|
|
// Sections
|
|
SECTION("TextureObject as nullptr") {
|
|
ret = hipCreateTextureObject(nullptr, &resDesc, &texDesc, nullptr);
|
|
REQUIRE(ret != hipSuccess);
|
|
}
|
|
|
|
SECTION("Resouce Descriptor as nullptr") {
|
|
ret = hipCreateTextureObject(&texObj, nullptr, &texDesc, nullptr);
|
|
REQUIRE(ret != hipSuccess);
|
|
}
|
|
|
|
SECTION("Texture Descriptor as nullptr") {
|
|
if ((TestContext::get()).isAmd()) {
|
|
ret = hipCreateTextureObject(&texObj, &resDesc, nullptr, nullptr);
|
|
REQUIRE(ret != hipSuccess);
|
|
} else {
|
|
// API expected to return failure. Test skipped
|
|
// on nvidia as api returns success and would lead
|
|
// to unexpected behavior with app.
|
|
WARN("Skipping section: " << HipTest::SkipReason::kApiUnsupportedOnNvidia);
|
|
}
|
|
}
|
|
|
|
SECTION("Destroy TextureObject with nullptr") {
|
|
ret = hipDestroyTextureObject((hipTextureObject_t) nullptr);
|
|
// api to return success and no crash seen.
|
|
REQUIRE(ret == hipSuccess);
|
|
}
|
|
|
|
// De-Initialization
|
|
HIP_CHECK(hipFree(texBuf));
|
|
}
|
|
|
|
/**
|
|
* End doxygen group TextureTest.
|
|
* @}
|
|
*/
|